@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.11 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.11 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -50,27 +50,34 @@ class SyL_ConfigFilters extends SyL_Config
      * @access private
      * @var string
      */
-    var $filter_event_before = 'loadStream';
+    var $filter_event_pre_action = 'executeStream';
     /**
-     * ե륿٥ȡʥ塢ӥ塼ɽ
+     * ե륿٥ȡʥ
      * 
      * @access private
      * @var string
      */
-    var $filter_event_mid = 'middleStream';
+    var $filter_event_post_action = 'middleStream';
     /**
      * ե륿٥ȡʥӥ塼ɽ
      * 
      * @access private
      * @var string
      */
-    var $filter_event_after = 'unloadStream';
+    var $filter_event_pre_render = 'renderStream';
+    /**
+     * ե륿٥ȡʥӥ塼ɽ
+     * 
+     * @access private
+     * @var string
+     */
+    var $filter_event_post_render = 'unloadStream';
     /**
      * ǥեȼ¹Խ
      * 
      * @param int
      */
-    var $default_priority = 7;
+    var $default_priority = 2;
     /**
      * ե̾
      * 
@@ -176,33 +183,37 @@ class SyL_ConfigFilters extends SyL_Config
             if (!$name) return;
 
             switch ($current_path) {
-            case '/filters/filter/before':
-               $method_name = 'method:' . $attribute['name'];
-               // ٥ȥ
-               $this->config[$name]['event'][$this->filter_event_before][] = $method_name;
+            case '/filters/filter/preAction':
+               $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'preAction');
+               $this->config[$name]['event'][$this->filter_event_pre_action][] = $method_name;
+               $this->config[$name]['args'][$method_name] = array();
+               break;
+
+            case '/filters/filter/postAction':
+               $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'postAction');
+               $this->config[$name]['event'][$this->filter_event_post_action][] = $method_name;
+               $this->config[$name]['args'][$method_name] = array();
+               break;
+
+            case '/filters/filter/preRender':
+               $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'preRender');
+               $this->config[$name]['event'][$this->filter_event_pre_render][] = $method_name;
                $this->config[$name]['args'][$method_name]  = array();
                break;
 
-            case '/filters/filter/mid':
-               $method_name = 'method:' . $attribute['name'];
-               // ٥ȥ
-               $this->config[$name]['event'][$this->filter_event_mid][] = $method_name;
+            case '/filters/filter/postRender':
+               $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'postRender');
+               $this->config[$name]['event'][$this->filter_event_post_render][] = $method_name;
                $this->config[$name]['args'][$method_name]  = array();
                break;
 
-            case '/filters/filter/after':
-               $method_name = 'method:' . $attribute['name'];
-               // ٥ȥ
-               $this->config[$name]['event'][$this->filter_event_after][] = $method_name;
-               $this->config[$name]['args'][$method_name]  = array();
-               break;
-
-            case '/filters/filter/mid/arg':
-            case '/filters/filter/before/arg':
-            case '/filters/filter/after/arg':
+            case '/filters/filter/preAction/arg':
+            case '/filters/filter/postAction/arg':
+            case '/filters/filter/preRender/arg':
+            case '/filters/filter/postRender/arg':
                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-               $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
+               $this->config[$name]['args'][$method_name][] = "{$type}:{$ref}:{$text}";
                break;
             }
         }
