@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.7 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.8 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,19 +53,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.7 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.8 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerWeb extends SyL_Controller
 {
-    /**
-     * ¹Ƚ
-     * 
-     * @access private
-     * @var bool
-     */
-    var $is_execute_action = true;
-
     /**
      * 󥹥ȥ饯
      *
@@ -127,10 +119,8 @@ class SyL_ControllerWeb extends SyL_Controller
     {
         // ¹Ƚ
         $config_file = array();
-        if ($this->isExecuteAction()) {
-            // ե
-            $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";
-        }
+        // ե
+        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";
 
         // ٥ȼ¹
         $this->raiseEvent('executeStream', $config_file);
@@ -173,28 +163,6 @@ echo "</pre>";
     {
         return $this->template_dir;
     }
-
-    /**
-     * ¹Ƚ򥻥å
-     * 
-     * @access public
-     * @return bool true: ¹Ԥ롢false: ¹Ԥʤ
-     */
-    function setExecuteAction($is_execute_action)
-    {
-        $this->is_execute_action = ($is_execute_action !== false);
-    }
-
-    /**
-     * ¹Ƚ
-     * 
-     * @access public
-     * @return bool true: ¹Ԥ롢false: ¹Ԥʤ
-     */
-    function isExecuteAction()
-    {
-        return $this->is_execute_action;
-    }
 }
 
 ?>
