@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.4 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_RequestParameter.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.4 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameterSession.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestParameterSession extends SyL_RequestParameter
@@ -210,9 +210,9 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
      * @access public
      * @return mixed åID
      */
-    function getSid()
+    function getSessionId()
     {
-        return urlencode(session_id());
+        return session_id();
     }
 
     /**
@@ -223,7 +223,7 @@ class SyL_RequestParameterSession extends SyL_RequestParameter
      */
     function getSidQuery()
     {
-        return strip_tags(SID);
+        return session_name() . '=' . session_id();
     }
 }
 
