@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.8 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.9 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ComponentMethod.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.8 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.9 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataManager
@@ -227,6 +227,70 @@ class SyL_DataManager
         $this->view_parameters[$name] = $value;
     }
 
+    /**
+     * ɥե򥻥å
+     *
+     * ɥե̾ꤷʤϡContent-Disposition: inline ˤʤ
+     * 
+     * @access public
+     * @param string ɥեѥ
+     * @param string ɥե̾
+     * @param string ƥĥ
+     */
+    function setDownloadFile($file, $filename='', $type='application/octet-stream')
+    {
+        $data = file_get_contents($file);
+        if ($data === false) {
+            trigger_error("[SyL error] Download data unable to get file ($file)", E_USER_ERROR);
+        }
+        $this->setDownloadData($data, $filename, $type);
+    }
+
+    /**
+     * ɥǡ򥻥å
+     * 
+     * ɥե̾ꤷʤϡContent-Disposition: inline ˤʤ
+     *
+     * @access public
+     * @param string ɥեѥ
+     * @param string ɥե̾
+     * @param string ƥĥ
+     */
+    function setDownloadData($data, $filename='', $type='application/octet-stream')
+    {
+        $this->setViewParameter('viewtype',   'download');
+        $this->setViewParameter('viewlayout', 'false');
+        $this->setParameter('_download_name', $filename);
+        $this->setParameter('_download_type', $type);
+        $this->setParameter('_download_data', $data);
+    }
+
+    /**
+     * ϲե򥻥å
+     *
+     * @access public
+     * @param string ɥեѥ
+     * @param string ƥĥ
+     */
+    function setDisplayImageFile($file, $type='')
+    {
+        if (!$type) {
+            $size = getimagesize($file);
+            if (!$size || !isset($size['mime'])) {
+                trigger_error("[SyL error] Image mime unable to get from getimagesize function ($file)", E_USER_ERROR);
+            }
+            $type = $size['mime'];
+        }
+        $data = file_get_contents($file);
+        if ($data === false) {
+            trigger_error("[SyL error] Display Image data unable to get file ($file)", E_USER_ERROR);
+        }
+        $this->setViewParameter('viewtype',   'image');
+        $this->setViewParameter('viewlayout', 'false');
+        $this->setParameter('_image_type', $type);
+        $this->setParameter('_image_data', $data);
+    }
+
     /**
      * ӥ塼ѥ᡼
      * 
@@ -242,7 +306,7 @@ class SyL_DataManager
     /**
      * ѥ
      * 
-     * @access public
+     * @access private
      * @param string ѥ
      * @return string ѥ
      */
@@ -286,17 +350,6 @@ class SyL_DataManager
         return $this->cm->triggerApp($name, $args);
     }
 
-    /**
-     * ¹Ƚ򥻥å
-     * 
-     * @access public
-     * @param bool true: ¹Ԥ롢false: ¹Ԥʤ
-     */
-    function setExecuteAction($is_execute_action)
-    {
-        $this->controller->setExecuteAction($is_execute_action);
-    }
-
     /**
      * ݡͥȥ֥Ȥ򥻥å
      * 
@@ -309,9 +362,8 @@ class SyL_DataManager
         return $this->controller->container->getComponent($name);
     }
 
-
     /**
-     * 쥤ȥѥ᡼򥻥å
+     * ѥ᡼򥻥å
      * 
      * @access public
      * @param string ѥ᡼̾
@@ -323,7 +375,7 @@ class SyL_DataManager
     }
 
     /**
-     * 쥤ȥѥ᡼򥻥åȡʻȡ
+     * ѥ᡼򥻥åȡʻȡ
      *
      * @access public
      * @param string ѥ᡼̾
@@ -334,17 +386,6 @@ class SyL_DataManager
         $this->parameters[$name] =& $value;
     }
 
-    /**
-     * ѥ᡼
-     * 
-     * @access public
-     * @return array ѥ᡼
-     */
-    function &getParameters()
-    {
-        return $this->parameters;
-    }
-
     /**
      * 󥪥֥Ȥ򥻥å
      * 
@@ -381,12 +422,25 @@ class SyL_DataManager
                 $action_class = $this->getClassName();
                 if (class_exists($action_class)) {
                     foreach (get_class_vars($action_class) as $key => $value) {
-                        $this->setParameter($key, $value);
+                        if (substr($key, 0, 1) != '_') {
+                            $this->setParameter($key, $value);
+                        }
                     }
                 }
             }
         }
     }
+
+    /**
+     * ѥ᡼
+     * 
+     * @access public
+     * @return array ѥ᡼
+     */
+    function &getParameters()
+    {
+        return $this->parameters;
+    }
 }
 
 ?>
