@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.15 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.16 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * եɤ߹९饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
-
 /**
  * ̹ǥ饹
  *
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.15 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.16 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -122,12 +117,17 @@ class SyL_View
     {
         $view = null;
         $type = $dm->getViewParameter('viewtype');
+        $class_name = '';
+        $class_file = '';
         if ($dm->getViewParameter('viewlayout') === 'true') {
             // Layout 饹
             switch ($type) {
-            case 'smarty' : $class_name = 'SyL_ViewLayoutSmarty';  break;
-            case 'default': $class_name = 'SyL_ViewLayoutDefault'; break;
-            default: trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
+            case 'smarty' :
+            case 'default':
+                $class_name = 'SyL_ViewLayout' . ucfirst($type);
+                break;
+            default:
+                trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
             }
             $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
             include_once $class_file;
@@ -146,24 +146,14 @@ class SyL_View
                     $class_file = $class_file1;
                 }
                 break;
-            case 'smarty':
-                $class_name = 'SyL_ViewSmarty';
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-                break;
-            case 'js':
-                $class_name = 'SyL_ViewJs';
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-                break;
             case 'ajax':
-                $class_name = 'SyL_ViewAjax';
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-                break;
-            case 'json':
-                $class_name = 'SyL_ViewJson';
-                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
-                break;
             case 'default':
-                $class_name = 'SyL_ViewDefault';
+            case 'download':
+            case 'image':
+            case 'js':
+            case 'json':
+            case 'smarty':
+                $class_name = 'SyL_View' . ucfirst($type);
                 $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
                 break;
             default:
@@ -184,6 +174,9 @@ class SyL_View
      */
     function parseConfig(&$controller)
     {
+        // եɤ߹९饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
+
         $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
         $reader =& SyL_Config::getObject('layouts', $config_file, $controller);
         $reader->parseXML();
@@ -269,6 +262,39 @@ class SyL_View
     {
     }
 
+    /**
+     * ɽƤ򥻥å
+     * 
+     * @access public
+     * @param string ɽ
+     */
+    function setRender(&$render)
+    {
+        $this->render =& $render;
+    }
+
+    /**
+     * ɽƤ
+     * 
+     * @access public
+     * @return string HTML
+     */
+    function &getRender()
+    {
+        return $this->render;
+    }
+
+    /**
+     * ɽƤ
+     * 
+     * @access public
+     */
+    function clearRender()
+    {
+        unset($this->render);
+        $this->render = '';
+    }
+
     /**
      * ƥĥפ򥻥å
      * 
@@ -312,39 +338,6 @@ class SyL_View
     {
         return (SYL_RESPONSE_GZIP) ? $this->gzip_compress : false;
     }
-
-    /**
-     * ɽƤ򥻥å
-     * 
-     * @access public
-     * @param string ɽ
-     */
-    function setRender(&$render)
-    {
-        $this->render =& $render;
-    }
-
-    /**
-     * ɽƤ
-     * 
-     * @access public
-     * @return string HTML
-     */
-    function &getRender()
-    {
-        return $this->render;
-    }
-
-    /**
-     * ɽƤ
-     * 
-     * @access public
-     */
-    function clearRender()
-    {
-        unset($this->render);
-        $this->render = '';
-    }
 }
 
 
