@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -69,6 +69,9 @@ class SyL_ViewSmarty extends SyL_View
         $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
         $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
         $this->smarty->cache_dir   = SYL_SMARTY_CACHE_DIR;
+
+        // ƥĥפ򥻥å
+        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
     }
 
     /**
