@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSmtp.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSmtp.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,14 +35,7 @@
 /**
  * å³饹
  */
-require_once dirname(dirname(__FILE__)) . '/SyL_Socket.php';
-
-/**
- * ᡼륵С
- */
-if (!defined('SYL_MAIL_TYPE')) {
-    define('SYL_MAIL_TYPE', 'Smtp::');
-}
+require_once dirname(dirname(__FILE__)) . '/Util/SyL_UtilSocket.php';
 
 /**
  * SMTP᡼饹
@@ -51,7 +44,7 @@ if (!defined('SYL_MAIL_TYPE')) {
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSmtp.php,v 1.9 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSmtp.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailSmtp extends SyL_Mail
@@ -71,7 +64,7 @@ class SyL_MailSmtp extends SyL_Mail
      */
     var $port = 25;
     /**
-     * 
+     * SMTPޥɥ
      *
      * @access private
      * @var string
@@ -88,20 +81,17 @@ class SyL_MailSmtp extends SyL_Mail
     /**
      * 󥹥ȥ饯
      *
-     * @access private
+     * @access public
+     * @param string ѥ᡼
      */
-    function SyL_MailSmtp()
+    function SyL_MailSmtp($type)
     {
-        $tmp = explode(':', SYL_MAIL_TYPE, 3);
-        if (strtolower($tmp[0]) != 'smtp') {
-            $tmp[2] = $tmp[1];
-            $tmp[1] = $tmp[0];
+        $tmp = explode(':', $type, 2);
+        if ($tmp[0] != '') {
+            $this->setHost($tmp[0]);
         }
-        if ($tmp[1] != '') {
-            $this->host = $tmp[1];
-        }
-        if (isset($tmp[2]) && is_numeric($tmp[2])) {
-            $this->port = $tmp[2];
+        if (isset($tmp[1]) && is_numeric($tmp[1])) {
+            $this->setPort($tmp[1]);
         }
         parent::SyL_Mail();
     }
@@ -133,13 +123,10 @@ class SyL_MailSmtp extends SyL_Mail
      *
      * @access public
      * @param array ᡼°
-     * @param bool ե饰
      */
     function init($attributes=array())
     {
-        $attributes = array_change_key_case($attributes, CASE_LOWER);
         parent::init($attributes);
-
         // ۥȥå
         if (isset($attributes['host'])) {
             $this->host = $attributes['host'];
@@ -154,24 +141,15 @@ class SyL_MailSmtp extends SyL_Mail
      * ᡼륵С³
      *
      * @access public
-     * @param string ᡼륵С
-     * @param int ݡֹ
      * @return OK: true, NG: false
      */
-    function connect($server='', $port=25)
+    function connect()
     {
-        if ($server != '') {
-            $this->setHost($server);
-        }
-        if ($port != '') {
-            $this->setPort($port);
-        }
-
         if (is_object($this->socket)) {
             $this->quit();
         }
         // åȥ֥Ⱥ
-        $this->socket = new SyL_Socket($this->host, $this->port);
+        $this->socket = new SyL_UtilSocket($this->host, $this->port);
         $this->socket->setCommandCallBackFunc(array(&$this, 'receiveMessage'));
 
         if (!$this->socket->open()) {
@@ -198,12 +176,12 @@ class SyL_MailSmtp extends SyL_Mail
     function send()
     {
         // Fromɬ
-        if ($this->headers['MAIL_FROM'] == '') {
+        if ($this->mail_property['MAIL_FROM'] == '') {
             $this->error_message = "[SyL error] From Address not found";
             return false;
         }
         // Toɬ
-        if (count($this->headers['To']) == 0) {
+        if (count($this->mail_property['RCPT_TO']) == 0) {
             $this->error_message = "[SyL error] To Address not found";
             return false;
         }
@@ -218,11 +196,11 @@ class SyL_MailSmtp extends SyL_Mail
         // ޥȯ ------------------------------------------------------------
 
         // åȥå
-        $this->socket->send('MAIL FROM: ' . $this->headers['MAIL_FROM']);
+        $this->socket->send('MAIL FROM: ' . $this->mail_property['MAIL_FROM']);
         // åȥå
         $this->socket->receive();
 
-        foreach ($this->headers['RCPT_TO'] as $to) {
+        foreach ($this->mail_property['RCPT_TO'] as $to) {
             // 襻åȥå
             $this->socket->send('RCPT TO: ' . $to);
             // 襻åȥå
@@ -243,9 +221,10 @@ class SyL_MailSmtp extends SyL_Mail
         // ǡåȥå
         $this->socket->receive();
 
-        // ᡼إåޤʸ
         // .פϥ
-        $data = $this->getHeaderMessage(preg_replace('/(\r\n|\n|\r)\.(\r\n|\n|\r)/s', '$1..$2', $this->body));
+        $this->body = preg_replace('/(\r\n|\n|\r)\.(\r\n|\n|\r)/s', '$1..$2', $this->body);
+        // ᡼إåޤʸ
+        $data = $this->createSendMessage();
         // Ǹˡ.פղ
         $data .= '.';
 
