@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.9 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.9 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -318,12 +318,12 @@ class SyL_DB
     {
         // SQL¸
         $this->log('begin');
-  
-        if (class_exists('SyL_Error')) {
+          if (class_exists('SyL_Error')) {
             $e =& SyL_Error::getInstance();
             $e->resetErrorHandler();
         }
         $this->transaction = true;
+        return true;
     }
 
     /**
@@ -335,12 +335,12 @@ class SyL_DB
     {
         // SQL¸
         $this->log('rollback');
-
         if (class_exists('SyL_Error')) {
             $e =& SyL_Error::getInstance();
             $e->setErrorHandler();
         }
         $this->transaction = false;
+        return true;
     }
 
     /**
@@ -350,15 +350,15 @@ class SyL_DB
      */
     function commit()
     {
-      // SQL¸
-      $this->log('commit');
-
-      if (class_exists('SyL_Error')) {
-          $e =& SyL_Error::getInstance();
-          $e->setErrorHandler();
-      }
-      $this->transaction = false;
-  }
+        // SQL¸
+        $this->log('commit');
+        if (class_exists('SyL_Error')) {
+            $e =& SyL_Error::getInstance();
+            $e->setErrorHandler();
+        }
+        $this->transaction = false;
+        return true;
+    }
 
     /**
      * SQL¹Ԥ̼
@@ -506,8 +506,8 @@ class SyL_DB
      */
     function &getPager($limit=20, $page=1)
     {
-        include_once dirname(__FILE__) . '/SyL_Pager.php';
-        $pager = new SyL_Pager();
+        include_once dirname(__FILE__) . '/Util/SyL_UtilPager.php';
+        $pager = new SyL_UtilPager();
         $pager->setCount($limit);
         $pager->setPage($page);
         return $pager;
