@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParserOperation.php,v 1.11 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParserOperation.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,8 +37,8 @@
  */
 require_once 'SyL_XMLParser.php';
 
-if (!defined('SYL_SCRIPT_ENCODE')) {
-    define('SYL_SCRIPT_ENCODE', 'EUC-JP');
+if (!defined('SYL_ENCODE_INTERNAL')) {
+    define('SYL_ENCODE_INTERNAL', 'EUC-JP');
 }
 
 /**
@@ -48,7 +48,7 @@ if (!defined('SYL_SCRIPT_ENCODE')) {
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParserOperation.php,v 1.11 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParserOperation.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_XMLParserOperation extends SyL_XMLParser
@@ -59,7 +59,7 @@ class SyL_XMLParserOperation extends SyL_XMLParser
      * @access private
      * @var string
      */
-    var $script_encde = SYL_SCRIPT_ENCODE;
+    var $script_encde = SYL_ENCODE_INTERNAL;
     /**
      * XMLΥγ
      *
